==> treuchtlingen-foxde-config_1.6.1.orig.tar.gz: treuchtlingen-foxde-config-1.6.1/kde-configuration/wahl-x2go/kactivitymanagerd.sql <==
PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE SchemaInfo (key text PRIMARY KEY, value text);
INSERT INTO SchemaInfo VALUES('version','2015.02.09');
CREATE TABLE ResourceEvent (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, start INTEGER, end INTEGER );
CREATE TABLE ResourceScoreCache (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, scoreType INTEGER, cachedScore FLOAT, firstUpdate INTEGER, lastUpdate INTEGER, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
CREATE TABLE ResourceLink (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:firefox-esr.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-fernfuchs-share.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-writer.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-calc.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:org.kde.dolphin.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:org.kde.kcalc.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:foxde-exit-logout.desktop');
CREATE TABLE ResourceInfo (targettedResource TEXT, title TEXT, mimetype TEXT, autoTitle INTEGER, autoMimetype INTEGER, PRIMARY KEY(targettedResource));
COMMIT;

==> treuchtlingen-foxde-config_1.6.3.orig.tar.gz: treuchtlingen-foxde-config-1.6.3/kde-configuration/wahl-x2go/kactivitymanagerd.sql <==
PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE SchemaInfo (key text PRIMARY KEY, value text);
INSERT INTO SchemaInfo VALUES('version','2015.02.09');
CREATE TABLE ResourceEvent (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, start INTEGER, end INTEGER );
CREATE TABLE ResourceScoreCache (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, scoreType INTEGER, cachedScore FLOAT, firstUpdate INTEGER, lastUpdate INTEGER, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
CREATE TABLE ResourceLink (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:firefox-esr.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-fernfuchs-share.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-writer.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:libreoffice-calc.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:org.kde.dolphin.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:org.kde.kcalc.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:de.treuchtlingen.firefox.wes.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:foxde-exit-logout.desktop');
CREATE TABLE ResourceInfo (targettedResource TEXT, title TEXT, mimetype TEXT, autoTitle INTEGER, autoMimetype INTEGER, PRIMARY KEY(targettedResource));
COMMIT;
